{% extends 'layouts/base.html' %}
{% load crispy_forms_tags %}
{% block title %}
    Profile
{% endblock title %}
{% block css %}
    <style>
        label{
            margin-top: 15px;
        }
    </style>
{% endblock css %}
{% block content %}

<div class="container pt-3 mt-5">
    <div class="card">
      <div class="card-header">
        <h5>PROFILE</h5>
      </div>
      <div class="card-body">
        <form method="post">
            {% csrf_token %}
            {{form|crispy}}
            <button class="btn btn-info btn-sm mt-2 text-white">Submit</button>
            <br>
            <h6 class="">
                <a href="{% url 'change-password' %}" style="text-decoration: none;color: inherit;">Change Password?</a>
            </h6>
        </form>
      </div>
    </div>
</div>
{% endblock content %}