{% extends 'layouts/base.html' %}
{% load crispy_forms_tags %}
{% block title %}
    Sign In
{% endblock title %}
{% block content %}

<div class="container pt-3 mt-5">
    <div class="card">
      <div class="card-header">
        <h5>SIGN IN</h5>
      </div>
      <div class="card-body">
        <form method="post">
            {% csrf_token %}
            {{form|crispy}}
            <button class="btn btn-info btn-sm mt-2 text-white">Submit</button>
            <br>
            <h6 class="mt-1">
                <a href="{% url 'reset-password' %}" style="text-decoration: none;color: inherit;">Forget password?</a>
            </h6>
            <h6 class="mt-3">
                Don't have an account? <a href="{% url 'signup' %}"
                style="text-decoration: none;color: white;"
                class="btn btn-info btn-sm">
                SIGN UP
                </a>
            </h6>
        </form>
      </div>
    </div>
  </div>

{% endblock content %}