{% extends 'layouts/base.html' %}
{% load crispy_forms_tags %}
{% block title %}
    Forget Password Confirm
{% endblock title %}
{% block content %}


<div class="container pt-3 mt-5">
    <div class="card">
      <div class="card-header">
        <h5>FORGET PASSWORD CONFIRM</h5>
      </div>
      <div class="card-body">
        <form method="post">
            {% csrf_token %}
            {{form|crispy}}
            <button class="btn btn-info btn-sm mt-2 text-white">Submit</button>
        </form>
      </div>
    </div>
</div>

{% endblock content %}